==> utilary-1.0.4.tar.gz: lib/src/array2d.dart <==
import "dart:collection";
import "vector.dart";
import 'rectangle.dart';

typedef T _NullaryGenerator<T>();
typedef T _VectorGenerator<T>(Vector pos);
typedef T _CoordinateGenerator<T>(int x, int y);

class Array2D<T> extends IterableBase<T> {
  final List<T> _data;
  final int rows;
  final int cols;

  Rectangle get bounds => Rectangle(0, 0, cols, rows);

  Array2D(this.rows, this.cols, [T defaultValue]) : _data = List<T>(rows * cols) {
    if (defaultValue != null) for (int i = 0; i < _data.length; i++) _data[i] = defaultValue;
  }

  ///Create a new [Array2D] with [rows], [cols] initializing
  ///its values to the result of the function [generator].
  ///[generator] can take `0` arguments, one `Vector` or
  ///two integers `(int x, int y)`.
  Array2D.generated(this.rows, this.cols, Function generator) : _data = List<T>(rows * cols) {
    _generate(generator);
  }

  ///Set every element to the result of [generator]
  void _generate(Function generator) {
    if (generator is _NullaryGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator();
    } else if (generator is _VectorGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator(pos);
    } else if (generator is _CoordinateGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator(pos.x, pos.y);
    }
  }

  int _cartesianToIndex(int x, int y) => y * cols + x;

  void set(int x, int y, T element) {
    _data[_cartesianToIndex(x, y)] = element;
  }

  T get(int x, int y) => _data[_cartesianToIndex(x, y)];

  T operator [](Vector i) => _data[_cartesianToIndex(i.x, i.y)];

  void operator []=(Vector i, T element) {
    _data[_cartesianToIndex(i.x, i.y)] = element;
  }

  Iterator<T> get iterator => _data.iterator;
}

==> utilary-1.0.8.tar.gz: lib/src/array2d.dart <==
import "dart:collection";
import "vector.dart";
import 'rectangle.dart';

typedef T _NullaryGenerator<T>();
typedef T _VectorGenerator<T>(Vector pos);
typedef T _CoordinateGenerator<T>(int x, int y);

class Array2D<T> extends IterableBase<T> {
  final List<T> _data;
  final int rows;
  final int cols;

  Rectangle get bounds => Rectangle(0, 0, cols, rows);

  Array2D(this.rows, this.cols, [T defaultValue])
      : _data = List<T>(rows * cols) {
    if (defaultValue != null)
      for (int i = 0; i < _data.length; i++) _data[i] = defaultValue;
  }

  ///Create a new [Array2D] with [rows], [cols] initializing
  ///its values to the result of the function [generator].
  ///[generator] can take `0` arguments, one `Vector` or
  ///two integers `(int x, int y)`.
  Array2D.generated(this.rows, this.cols, Function generator)
      : _data = List<T>(rows * cols) {
    _generate(generator);
  }

  ///Set every element to the result of [generator]
  void _generate(Function generator) {
    if (generator is _NullaryGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator();
    } else if (generator is _VectorGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator(pos);
    } else if (generator is _CoordinateGenerator<T>) {
      for (Vector pos in bounds) this[pos] = generator(pos.x, pos.y);
    }
  }

  int _cartesianToIndex(int x, int y) => y * cols + x;

  void set(int x, int y, T element) {
    _data[_cartesianToIndex(x, y)] = element;
  }

  T get(int x, int y) => _data[_cartesianToIndex(x, y)];

  T operator [](Vector i) => _data[_cartesianToIndex(i.x, i.y)];

  void operator []=(Vector i, T element) {
    _data[_cartesianToIndex(i.x, i.y)] = element;
  }

  Iterator<T> get iterator => _data.iterator;
}
